@@ -86,7 +86,7 @@
 #define KICONTHEMES_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KICONTHEMES_NO_DEPRECATED
-#  define KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54600
+#  define KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
 #endif
 #ifdef KICONTHEMES_NO_DEPRECATED_WARNINGS
 #  define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0x54600
+#    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0x54c00
 #  endif
 #endif
 
@@ -148,5 +148,6 @@
 #define KICONTHEMES_DEPRECATED_VERSION_4(minor, text)      KICONTHEMES_DEPRECATED_VERSION_4_##minor(text)
 #define KICONTHEMES_DEPRECATED_VERSION_5(minor, text)      KICONTHEMES_DEPRECATED_VERSION_5_##minor(text)
 #define KICONTHEMES_DEPRECATED_VERSION(major, minor, text) KICONTHEMES_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KICONTHEMES_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KICONTHEMES_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KICONTHEMES_EXPORT_H */
